@@ -127,15 +127,9 @@ class WifiSetupDialog(QDialog, Ui_Dialog):
         self.InfoIcon.setPixmap(load_pixmap("info", "16x16"))
 
         if self.standalone:
-            self.MainTitleLabel.setText(self.__tr("""This utility allows you configure your wireless capable printer using a temporary USB connection. You will be prompted to disconnect the USB cable once wireless network setup is complete.
-
-<p><i>Note: This configuration utility does not setup (install) your printer on this computer. Use hp-setup to setup your printer after it has been configured on the network by this utility.</i></p>
-<p><i>Note: Only select wireless capable printers are supported by this utility.</i></p>"""))
+            self.MainTitleLabel.setText(self.__tr("This utility allows you configure your wireless capable printer using a temporary USB connection. You will be prompted to disconnect the USB cable once wireless network setup is complete. <p><i>Note: This configuration utility does not setup (install) your printer on this computer. Use hp-setup to setup your printer after it has been configured on the network by this utility.</i></p> <p><i>Note: Only select wireless capable printers are supported by this utility.</i></p>"))
         else:
-            self.MainTitleLabel.setText(self.__tr("""This utility allows you configure your wireless capable printer using a temporary USB connection. You will be prompted to disconnect the USB cable once wireless network setup is complete.
-
-<p><i>Note: Printer setup (installation) will continue after your printer is configured on the network.</i></p>
-<p><i>Note: Only select wireless capable printers are supported by this utility.</i></p>"""))
+            self.MainTitleLabel.setText(self.__tr("This utility allows you configure your wireless capable printer using a temporary USB connection. You will be prompted to disconnect the USB cable once wireless network setup is complete. <p><i>Note: Printer setup (installation) will continue after your printer is configured on the network.</i></p> <p><i>Note: Only select wireless capable printers are supported by this utility.</i></p>"))
 
 
     def showIntroPage(self):
@@ -259,7 +253,7 @@ class WifiSetupDialog(QDialog, Ui_Dialog):
             try:
                 self.dev = device.Device(self.device_uri)
             except Error as e:
-                FailureUI(self, self.__tr("<b>Error opening device:</b><p>%s</p><p>(%s)</p>") %(self.device_uri, str(e[0])))
+                FailureUI(self, self.__tr("<b>Error opening device:</b><p>%s</p><p>(%s)</p>") %(self.device_uri, str(e)))
 
                 if self.dev is not None:
                     self.dev.close()
@@ -569,6 +563,8 @@ class WifiSetupDialog(QDialog, Ui_Dialog):
         try:
             try:                
                 self.ip,_,addressmode, subnetmask, gateway, pridns, sec_dns= self.wifiObj.getIPConfiguration(self.dev, self.adapterName)
+                if self.ip == "0.0.0.0":
+                    self.ip, subnetmask, gateway, pri_dns, sec_dns, addressmode = self.wifiObj.getwifiotherdetails(self.dev,self.adapterName)
                 vsa_codes = self.wifiObj.getVSACodes(self.dev, self.adapterName)
                 ss_max, ss_min, ss_val, ss_dbm = self.wifiObj.getSignalStrength(self.dev, self.adapterName,self.network, self.adaptor_id)                 
                 self.hn = self.wifiObj.getHostname(self.dev) 
@@ -579,7 +575,7 @@ class WifiSetupDialog(QDialog, Ui_Dialog):
             self.dev.close()
             endWaitCursor()
 
-        if addressmode.lower() == 'dhcp':
+        if 'dhcp' or 'default' in addressmode.lower():
             self.success = SUCCESS_CONNECTED
 
         elif addressmode.lower() == 'autoip':
@@ -838,7 +834,7 @@ class WifiSetupDialog(QDialog, Ui_Dialog):
 
 
     def showIOError(self, e):
-        FailureUI(self, self.__tr("<b>An I/O error occurred.</b><p>Please check the USB connection to your printer and try again.</p>(%s)" % str(e[0])))
+        FailureUI(self, self.__tr("<b>An I/O error occurred.</b><p>Please check the USB connection to your printer and try again.</p>(%s)" % str(e)))
 
         if self.dev is not None:
             self.dev.close()
